# Documentation

This is where you can find the documentation source-code, if you want to view the live version of this documentation, you can do so [here](https://arc.hypergonial.com).

## Building

If you'd like to view the documentation locally yourself, simply run the nox session:

```sh
nox -s servedocs
```

Then open the URL provided to you in the terminal in your preferred browser.
